==> proton-native-1.0.11.tgz: package/README.md <==
<p align="center">
  <a href="https://proton-native.js.org">
    <img alt="proton native" src="https://cdn.rawgit.com/kusti8/proton-native/master/docs/SVG/Artboard%201.svg">
  </a>
</p>

[![npm](https://img.shields.io/npm/v/proton-native.svg)](https://www.npmjs.com/package/proton-native)
[![npm](https://img.shields.io/npm/dm/proton-native.svg)](https://www.npmjs.com/package/proton-native)
[![styled with prettier](https://img.shields.io/badge/styled_with-prettier-ff69b4.svg)](https://github.com/prettier/prettier)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](http://makeapullrequest.com)
[![GPLv3 License](https://img.shields.io/github/license/kusti8/proton-native.svg)](https://github.com/kusti8/proton-native/blob/master/LICENSE)

Create native desktop applications through a React syntax, on all platforms

## Features

- Same syntax as React Native
- Works with existing React libraries such as Redux
- Cross platform
- Native components. No more Electron

## Images

![Windows](docs/images/windows_example.png)

## [Documentation](https://proton-native.js.org)

See the documentation for how to get started and details on all the components.

## Examples

Examples can be found in `examples/`.

## Contributing

All contributions are welcome. Just make a PR. Below is a list of general improvements that need to be added that I would love help with:

- More examples and improve documentation
- Add UiArea
- Clean up code
- Make packaging easier
- Make creating a new app easier (something similar to `create-react-app`)

==> proton-native-1.0.13.tgz: package/README.md <==
<p align="center">
  <a href="https://proton-native.js.org">
    <img alt="proton native" src="docs/images/logo_black.svg">
  </a>
</p>

[![npm](https://img.shields.io/npm/v/proton-native.svg)](https://www.npmjs.com/package/proton-native)
[![npm](https://img.shields.io/npm/dm/proton-native.svg)](https://www.npmjs.com/package/proton-native)
[![styled with prettier](https://img.shields.io/badge/styled_with-prettier-ff69b4.svg)](https://github.com/prettier/prettier)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](http://makeapullrequest.com)
[![GPLv3 License](https://img.shields.io/github/license/kusti8/proton-native.svg)](https://github.com/kusti8/proton-native/blob/master/LICENSE)
[![Gitter chat](https://badges.gitter.im/gitterHQ/gitter.png)](https://gitter.im/Proton-Native)


Create native desktop applications through a React syntax, on all platforms

## Features

- Same syntax as React Native
- Works with existing React libraries such as Redux
- Cross platform
- Native components. No more Electron
- Compatible with all normal Node.js packages

## Images

![Windows](http://protonnative-af51.kxcdn.com/images/windows_example.png)

## [Documentation](https://proton-native.js.org)

See the documentation for how to get started and details on all the components.

## Examples

Examples can be found in `examples/`.

## Contributing

All contributions are welcome. Just make a PR. Below is a list of general improvements that need to be added that I would love help with:

- More examples and improve documentation
- Add UiArea
- Clean up code
- Make packaging easier
- Make creating a new app easier (something similar to `create-react-app`)

<a href="https://www.keycdn.com/"><sub><sup>Accelerated by KeyCDN</sup></sub></a>
